@@ -44,6 +44,7 @@ struct _GsPageClass
 						 GsApp		 *app);
 	void		(*switch_to)		(GsPage		 *page,
 						 gboolean	  scroll_up);
+	void		(*reload)		(GsPage		 *page);
 };
 
 GsPage		*gs_page_new				(void);
@@ -54,19 +55,26 @@ GtkWidget	*gs_page_get_header_end_widget		(GsPage		*page);
 void		 gs_page_set_header_end_widget		(GsPage		*page,
 							 GtkWidget	*widget);
 void		 gs_page_install_app			(GsPage		*page,
-							 GsApp		*app);
+							 GsApp		*app,
+							 GCancellable	*cancellable);
 void		 gs_page_remove_app			(GsPage		*page,
-							 GsApp		*app);
+							 GsApp		*app,
+							 GCancellable	*cancellable);
 void		 gs_page_update_app			(GsPage		*page,
-							 GsApp		*app);
+							 GsApp		*app,
+							 GCancellable	*cancellable);
 void		 gs_page_launch_app			(GsPage		*page,
-							 GsApp		*app);
+							 GsApp		*app,
+							 GCancellable	*cancellable);
 void		 gs_page_shortcut_add			(GsPage		*page,
-							 GsApp		*app);
+							 GsApp		*app,
+							 GCancellable	*cancellable);
 void		 gs_page_shortcut_remove		(GsPage		*page,
-							 GsApp		*app);
+							 GsApp		*app,
+							 GCancellable	*cancellable);
 void		 gs_page_switch_to			(GsPage		*page,
 							 gboolean	 scroll_up);
+void		 gs_page_reload				(GsPage		*page);
 void		 gs_page_setup				(GsPage		*page,
 							 GsShell	*shell,
 							 GsPluginLoader	*plugin_loader,
