@@ -359,12 +359,8 @@ gs_appstream_refine_app_updates (GsPlugin *plugin,
 	g_autoptr(GPtrArray) updates_list = NULL;
 
 	/* not enough data to make sense */
-	if (gs_app_get_version (app) == NULL) {
-		g_debug ("no installed version for %s, "
-			 "so unable to add AppStream releases",
-			 gs_app_get_id (app));
+	if (gs_app_get_version (app) == NULL)
 		return TRUE;
-	}
 
 	/* make a list of valid updates */
 	updates_list = g_ptr_array_new ();
@@ -502,16 +498,9 @@ gs_appstream_refine_app (GsPlugin *plugin,
 	}
 
 	/* is installed already */
-	if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN) {
-		switch (as_app_get_source_kind (item)) {
-		case AS_APP_SOURCE_KIND_APPDATA:
-		case AS_APP_SOURCE_KIND_DESKTOP:
-		case AS_APP_SOURCE_KIND_METAINFO:
-			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
-			break;
-		default:
-			break;
-		}
+	if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN &&
+	    as_app_get_state (item) != AS_APP_STATE_UNKNOWN) {
+		gs_app_set_state (app, as_app_get_state (item));
 	}
 
 	/* types we can never launch */
@@ -541,7 +530,10 @@ gs_appstream_refine_app (GsPlugin *plugin,
 		gs_app_set_id (app, as_app_get_id (item));
 
 	/* set source */
-	gs_app_set_metadata (app, "appstream::source-file", as_app_get_source_file (item));
+	if (gs_app_get_metadata_item (app, "appstream::source-file") == NULL) {
+		gs_app_set_metadata (app, "appstream::source-file",
+				     as_app_get_source_file (item));
+	}
 
 	/* scope */
 	if (gs_app_get_scope (app) == AS_APP_SCOPE_UNKNOWN &&
