@@ -40,7 +40,7 @@ struct _GsFlatpak {
 	FlatpakInstallation	*installation;
 	GHashTable		*broken_remotes;
 	GFileMonitor		*monitor;
-	GsFlatpakScope		 scope;
+	AsAppScope		 scope;
 	GsPlugin		*plugin;
 };
 
@@ -98,10 +98,10 @@ gs_flatpak_setup (GsFlatpak *self, GCancellable *cancellable, GError **error)
 		self->installation = flatpak_installation_new_for_path (file, TRUE,
 									cancellable,
 									error);
-	} else if (self->scope == GS_FLATPAK_SCOPE_SYSTEM) {
+	} else if (self->scope == AS_APP_SCOPE_SYSTEM) {
 		self->installation = flatpak_installation_new_system (cancellable,
 								      error);
-	} else if (self->scope == GS_FLATPAK_SCOPE_USER) {
+	} else if (self->scope == AS_APP_SCOPE_USER) {
 		self->installation = flatpak_installation_new_user (cancellable,
 								    error);
 	}
@@ -903,6 +903,10 @@ gs_plugin_refine_item_origin (GsFlatpak *self,
 	if (gs_app_get_origin (app) != NULL)
 		return TRUE;
 
+	/* not applicable */
+	if (gs_app_get_state(app) == AS_APP_STATE_AVAILABLE_LOCAL)
+		return TRUE;
+
 	/* ensure metadata exists */
 	ptask = as_profile_start_literal (gs_plugin_get_profile (self->plugin),
 					  "flatpak::refine-origin");
@@ -1233,6 +1237,10 @@ gs_plugin_refine_item_size (GsFlatpak *self,
 	guint64 installed_size = GS_APP_SIZE_UNKNOWABLE;
 	g_autoptr(AsProfileTask) ptask = NULL;
 
+	/* not applicable */
+	if (gs_app_get_state(app) == AS_APP_STATE_AVAILABLE_LOCAL)
+		return TRUE;
+
 	/* already set */
 	if (gs_app_is_installed (app)) {
 		/* only care about the installed size if the app is installed */
@@ -1284,8 +1292,9 @@ gs_plugin_refine_item_size (GsFlatpak *self,
 	 * and ignore the download size as this is faster */
 	if (gs_app_is_installed (app)) {
 		g_autoptr(FlatpakInstalledRef) xref = NULL;
-		xref = gs_flatpak_get_installed_ref (self, app,
-						     cancellable, error);
+		xref = gs_flatpak_get_installed_ref (self, app, cancellable, error);
+		if (xref == NULL)
+			return FALSE;
 		installed_size = flatpak_installed_ref_get_installed_size (xref);
 		if (installed_size == 0)
 			installed_size = GS_APP_SIZE_UNKNOWABLE;
@@ -1586,7 +1595,8 @@ gs_flatpak_app_install (GsFlatpak *self,
 	}
 
 	/* use the source for local apps */
-	if (gs_app_get_state (app) == AS_APP_STATE_AVAILABLE_LOCAL) {
+	if (gs_app_get_local_file (app) != NULL) {
+		g_debug ("installing bundle %s", gs_app_get_unique_id (app));
 		xref = flatpak_installation_install_bundle (self->installation,
 							    gs_app_get_local_file (app),
 							    gs_flatpak_progress_cb,
@@ -1963,7 +1973,7 @@ gs_flatpak_init (GsFlatpak *self)
 }
 
 GsFlatpak *
-gs_flatpak_new (GsPlugin *plugin, GsFlatpakScope scope)
+gs_flatpak_new (GsPlugin *plugin, AsAppScope scope)
 {
 	GsFlatpak *self;
 	self = g_object_new (GS_TYPE_FLATPAK, NULL);
